==> eiffelstudio-18.07.10.1981.tar: F_code/C1/ev43.c <==
/*
 * Code for class EV_GRID_ITEM_ACTION_SEQUENCES_I
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ev43.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.pointer_motion_actions */
EIF_REFERENCE F55_1784 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current) == NULL)) {
		tr1 = RTLNSMART(eif_new_type(788, 0).id);
		F764_5417(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	}
	RTLE;
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current);
}

/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.pointer_motion_actions_internal */
static EIF_REFERENCE F55_1785_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F55_1785 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current);
	if (!r) {
		if (RTAT(eif_new_type(788, 0))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F55_1785_body (Current));
			*(EIF_REFERENCE *)(Current) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.pointer_button_press_actions */
EIF_REFERENCE F55_1786 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_1_) == NULL)) {
		tr1 = RTLNSMART(eif_new_type(791, 0).id);
		F764_5417(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	}
	RTLE;
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current + _REFACS_1_);
}

/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.pointer_button_press_actions_internal */
static EIF_REFERENCE F55_1787_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F55_1787 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	if (!r) {
		if (RTAT(eif_new_type(791, 0))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F55_1787_body (Current));
			*(EIF_REFERENCE *)(Current + _REFACS_1_) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.pointer_double_press_actions */
EIF_REFERENCE F55_1788 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_2_) == NULL)) {
		tr1 = RTLNSMART(eif_new_type(791, 0).id);
		F764_5417(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	}
	RTLE;
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current + _REFACS_2_);
}

/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.pointer_double_press_actions_internal */
static EIF_REFERENCE F55_1789_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F55_1789 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	if (!r) {
		if (RTAT(eif_new_type(791, 0))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F55_1789_body (Current));
			*(EIF_REFERENCE *)(Current + _REFACS_2_) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.pointer_button_release_actions */
EIF_REFERENCE F55_1790 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_3_) == NULL)) {
		tr1 = RTLNSMART(eif_new_type(791, 0).id);
		F764_5417(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
	}
	RTLE;
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current + _REFACS_3_);
}

/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.pointer_button_release_actions_internal */
static EIF_REFERENCE F55_1791_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F55_1791 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	if (!r) {
		if (RTAT(eif_new_type(791, 0))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F55_1791_body (Current));
			*(EIF_REFERENCE *)(Current + _REFACS_3_) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.pointer_enter_actions */
EIF_REFERENCE F55_1792 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_4_) == NULL)) {
		tr1 = RTLNSMART(eif_new_type(790, 0).id);
		F764_5417(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) tr1;
	}
	RTLE;
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current + _REFACS_4_);
}

/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.pointer_enter_actions_internal */
static EIF_REFERENCE F55_1793_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F55_1793 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	if (!r) {
		if (RTAT(eif_new_type(790, 0))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F55_1793_body (Current));
			*(EIF_REFERENCE *)(Current + _REFACS_4_) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.pointer_leave_actions */
EIF_REFERENCE F55_1794 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_5_) == NULL)) {
		tr1 = RTLNSMART(eif_new_type(790, 0).id);
		F764_5417(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) tr1;
	}
	RTLE;
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current + _REFACS_5_);
}

/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.pointer_leave_actions_internal */
static EIF_REFERENCE F55_1795_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F55_1795 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_5_);
	if (!r) {
		if (RTAT(eif_new_type(790, 0))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F55_1795_body (Current));
			*(EIF_REFERENCE *)(Current + _REFACS_5_) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.key_press_actions_internal */
static EIF_REFERENCE F55_1797_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F55_1797 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	if (!r) {
		if (RTAT(eif_new_type(785, 0))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F55_1797_body (Current));
			*(EIF_REFERENCE *)(Current + _REFACS_6_) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.key_press_string_actions_internal */
static EIF_REFERENCE F55_1799_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F55_1799 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	if (!r) {
		if (RTAT(eif_new_type(784, 0))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F55_1799_body (Current));
			*(EIF_REFERENCE *)(Current + _REFACS_7_) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.key_release_actions_internal */
static EIF_REFERENCE F55_1801_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F55_1801 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_8_);
	if (!r) {
		if (RTAT(eif_new_type(785, 0))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F55_1801_body (Current));
			*(EIF_REFERENCE *)(Current + _REFACS_8_) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.select_actions_internal */
static EIF_REFERENCE F55_1804_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F55_1804 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_9_);
	if (!r) {
		if (RTAT(eif_new_type(790, 0))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F55_1804_body (Current));
			*(EIF_REFERENCE *)(Current + _REFACS_9_) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.deselect_actions_internal */
static EIF_REFERENCE F55_1805_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F55_1805 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_10_);
	if (!r) {
		if (RTAT(eif_new_type(790, 0))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F55_1805_body (Current));
			*(EIF_REFERENCE *)(Current + _REFACS_10_) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.drop_actions */
EIF_REFERENCE F55_1806 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_11_) == NULL)) {
		tr1 = RTLNSMART(eif_new_type(769, 0).id);
		F764_5417(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_11_) = (EIF_REFERENCE) tr1;
	}
	RTLE;
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current + _REFACS_11_);
}

/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.drop_actions_internal */
static EIF_REFERENCE F55_1807_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F55_1807 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_11_);
	if (!r) {
		if (RTAT(eif_new_type(769, 0))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F55_1807_body (Current));
			*(EIF_REFERENCE *)(Current + _REFACS_11_) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.activate_actions */
EIF_REFERENCE F55_1808 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_12_) == NULL)) {
		{
			static EIF_TYPE_INDEX typarr0[] = {768,0xFFF9,1,962,1185,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
			tr1 = RTLNSMART(typres0.id);
		}
		F764_5417(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_12_) = (EIF_REFERENCE) tr1;
	}
	RTLE;
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current + _REFACS_12_);
}

/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.activate_actions_internal */
static EIF_REFERENCE F55_1809_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F55_1809 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_12_);
	if (!r) {
		{
			static EIF_TYPE_INDEX typarr0[] = {768,0xFFF9,1,962,1185,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
			if (RTAT(typres0)) {
				GTCX
				RTLD;
				RTLI(1);
				RTLR(0,Current);
				RTLIU(1);
				r = (F55_1809_body (Current));
				*(EIF_REFERENCE *)(Current + _REFACS_12_) = r;
				RTAR(Current, r);
				RTLE;
			}
		}
	}
	return r;
}


/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.deactivate_actions */
EIF_REFERENCE F55_1810 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_13_) == NULL)) {
		tr1 = RTLNSMART(eif_new_type(790, 0).id);
		F764_5417(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_13_) = (EIF_REFERENCE) tr1;
	}
	RTLE;
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current + _REFACS_13_);
}

/* {EV_GRID_ITEM_ACTION_SEQUENCES_I}.deactivate_actions_internal */
static EIF_REFERENCE F55_1811_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F55_1811 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_13_);
	if (!r) {
		if (RTAT(eif_new_type(790, 0))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F55_1811_body (Current));
			*(EIF_REFERENCE *)(Current + _REFACS_13_) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


void EIF_Minit43 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.11.10.2592.tar: F_code/C1/ev43.c <==
/*
 * Code for class EV_GRID_ROW_ACTION_SEQUENCES_I
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ev43.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EV_GRID_ROW_ACTION_SEQUENCES_I}.deselect_actions */
EIF_REFERENCE F55_1803 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_1_) == NULL)) {
		tr1 = RTLNSMART(eif_new_type(794, 0).id);
		F649_5275(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	}
	RTLE;
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current + _REFACS_1_);
}

/* {EV_GRID_ROW_ACTION_SEQUENCES_I}.expand_actions */
EIF_REFERENCE F55_1804 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_2_) == NULL)) {
		tr1 = RTLNSMART(eif_new_type(794, 0).id);
		F649_5275(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	}
	RTLE;
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current + _REFACS_2_);
}

/* {EV_GRID_ROW_ACTION_SEQUENCES_I}.select_actions_internal */
static EIF_REFERENCE F55_1806_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F55_1806 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current);
	if (!r) {
		if (RTAT(eif_new_type(794, 0))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F55_1806_body (Current));
			*(EIF_REFERENCE *)(Current) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


/* {EV_GRID_ROW_ACTION_SEQUENCES_I}.deselect_actions_internal */
static EIF_REFERENCE F55_1807_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F55_1807 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	if (!r) {
		if (RTAT(eif_new_type(794, 0))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F55_1807_body (Current));
			*(EIF_REFERENCE *)(Current + _REFACS_1_) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


/* {EV_GRID_ROW_ACTION_SEQUENCES_I}.expand_actions_internal */
static EIF_REFERENCE F55_1808_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F55_1808 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	if (!r) {
		if (RTAT(eif_new_type(794, 0))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F55_1808_body (Current));
			*(EIF_REFERENCE *)(Current + _REFACS_2_) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


/* {EV_GRID_ROW_ACTION_SEQUENCES_I}.collapse_actions_internal */
static EIF_REFERENCE F55_1809_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F55_1809 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	if (!r) {
		if (RTAT(eif_new_type(794, 0))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F55_1809_body (Current));
			*(EIF_REFERENCE *)(Current + _REFACS_3_) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


void EIF_Minit43 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
